==> jquery-componets-1.0.2.tgz: package/src/index.js <==
import _ from 'lodash';
import JqComponent, { listenProps, setGlobalComponent, removeGlobalComponent } from './JqComponent';

export const useJquery = jQuery => {
  const $html = jQuery.prototype.html;
  const $attr = jQuery.prototype.attr;
  const $data = jQuery.prototype.data;

  jQuery.component = function (tagName, conf) {
    setGlobalComponent(_.toUpper(tagName), conf);
  };

  jQuery.unComponent = function(tagName) {
    removeGlobalComponent(_.toUpper(tagName))
  }

  jQuery.router = function (routers, tagName = 'router-view') {
    const routerChange = $ => {
      let hash = location.hash;
      hash = hash.replace('#', '');
      $.el.html('');
      routers.forEach(({ path, component }) => {
        if (_.startsWith(hash, path)) {
          $.el.html(component);
          listenProps.emit('all', 'router', hash);
          return false;
        }
      });
      return hash;
    }
    jQuery.component(tagName, {
      template: '<div component-router></div>',
      ready($) {
        routerChange($);
        window.onhashchange = () => {
          routerChange($);
        };
      }
    });
  }

  jQuery.prototype.attr = function () {
    let args = [...arguments];
    let [key, val] = args;
    let componentId = $attr.call(this, 'component-id');
    if (componentId) {
      listenProps.emit(componentId, key, val);
    }
    return $attr.apply(this, args);
  }

  jQuery.prototype.data = function () {
    let args = [...arguments];
    let [key, val] = args;
    let componentId = $attr.call(this, 'component-id');
    if (componentId) {
      listenProps.emit(componentId, key, val);
    }
    return $data.apply(this, args)
  }

  jQuery.prototype.html = function (obj) {
    if (_.isObject(obj)) {
      // 在根节点下动态生成一个占位组件标签
      const templateApp = 'template-' + Date.now() + '-' +  _.random(0, 1000);
      $html.call(this, `<${templateApp}></${templateApp}>`);
      // 注册这个组件
      jQuery.component(templateApp, obj);
      // 则生成组件实例，再渲染
      let jqc = new JqComponent(obj);
      jqc.render(this.get(0))
      // 销毁动态组件
      jQuery.unComponent(templateApp);
      return this;
    } else {
      return $html.call(this, obj)
    }
  }
};

==> jquery-componets-1.0.3.tgz: package/src/index.js <==
import _ from 'lodash';
import JqComponent, { listenProps, setGlobalComponent, removeGlobalComponent } from './JqComponent';

export const useJquery = jQuery => {
  const $html = jQuery.prototype.html;
  const $attr = jQuery.prototype.attr;
  const $data = jQuery.prototype.data;

  jQuery.component = function (tagName, conf) {
    return setGlobalComponent(_.toUpper(tagName), conf);
  };

  jQuery.unComponent = function(tagName) {
    return removeGlobalComponent(_.toUpper(tagName))
  }

  jQuery.router = function (routers, tagName = 'router-view') {
    const routerChange = $ => {
      let hash = location.hash;
      hash = hash.replace('#', '');
      $.el.html('');
      for (let router of routers) {
        let { path, component } = router;
        if (_.startsWith(hash, path)) {
          $.el.html(component);
          listenProps.emit('all', 'router', { hash, ...router });
          return;
        }
      }
      listenProps.emit('all', 'router', { hash });
    }
    jQuery.component(tagName, {
      template: '<div component-router></div>',
      ready($) {
        routerChange($);
        window.onhashchange = () => {
          routerChange($);
        };
      }
    });
  }

  jQuery.prototype.attr = function () {
    let args = [...arguments];
    let [key, val] = args;
    let componentId = $attr.call(this, 'component-id');
    if (componentId) {
      listenProps.emit(componentId, key, val);
    }
    return $attr.apply(this, args);
  }

  jQuery.prototype.data = function () {
    let args = [...arguments];
    let [key, val] = args;
    let componentId = $attr.call(this, 'component-id');
    if (componentId) {
      listenProps.emit(componentId, key, val);
    }
    return $data.apply(this, args)
  }

  jQuery.prototype.html = function (obj) {
    if (_.isObject(obj)) {
      // 在根节点下动态生成一个占位组件标签
      const templateApp = 'template-' + Date.now() + '-' +  _.random(0, 1000);
      $html.call(this, `<${templateApp}></${templateApp}>`);
      // 注册这个组件
      jQuery.component(templateApp, obj);
      // 则生成组件实例，再渲染
      let jqc = new JqComponent(obj);
      jqc.render(this.get(0))
      // 销毁动态组件
      jQuery.unComponent(templateApp);
      return this;
    } else {
      return $html.call(this, obj)
    }
  }
};
